@@ -16,7 +16,7 @@ def run(workflow, context):
 def main(workflows):
   vault = Vault()
   logmgr = LogMgr(vault)
-  logging.info("[+] Starting Laboro")
+  logging.getLogger().log_section("LABORO", "Bootstrapping")
   context = Context(logger=logmgr)
   for workflow in workflows:
     logging.getLogger().vault.clear()
