@@ -1,6 +1,7 @@
 import os
 import logging
 from laboro.error import LaboroError
+from laboro.history import History
 from laboro.config.manager import Manager as ConfigMgr
 from laboro.module.manager import Manager as ModuleMgr
 from laboro.error.handler import Handler as ErrorHandler
@@ -9,7 +10,9 @@ from laboro.error.handler import Handler as ErrorHandler
 class Context:
   def __init__(self, logger):
     self.logger = logger
+    self.memory = dict()
     self.modules = dict()
+    self.history = None
     self.modulemgr = ModuleMgr()
     self.configmgr = ConfigMgr("/etc/laboro/laboro.yml")
     self.workspacedir = self.configmgr.get_parameter("main",
@@ -24,7 +27,19 @@ class Context:
                                                  "$.laboro.log.level")
     logging.getLogger().vault.clear()
 
-  def configure_logger(self, workflow_name, session):
+  def reset(self, workflow_name, session):
+    logging.getLogger().vault.clear()
+    self.memory = dict()
+    self._configure_logger(workflow_name, session)
+    self.set_workflow_config(workflow_name)
+    self.history = History(filename=os.path.join(self.histdir,
+                                                 f"{workflow_name}.db"),
+                           workflow=workflow_name,
+                           session=session,
+                           params=self.configmgr.workflow_config)
+    return self
+
+  def _configure_logger(self, workflow_name, session):
     self.logger.add_file_handler(self.logdir, workflow_name, session)
     self.logger.set_log_level(self.loglevel)
 
