@@ -11,18 +11,28 @@ class Manager:
 
   terms = ["linux", "xterm", "xterm-256color"]
   console_fmt = '[%(asctime)s] [%(levelname)-8s] %(message)s'
-  file_fmt = '[%(asctime)s] [%(levelname)-8s] [%(name)s] %(message)s'
+  file_fmt = '[%(asctime)s] [%(levelname)-8s] %(message)s'
   datefmt = '%Y%m%d %H:%M:%S'
-  field_styles = {'asctime': {'color': 'magenta'},
-                  'hostname': {'color': 'magenta'},
-                  'levelname': {'color': 'white', 'bold': True},
-                  'programname': {'color': 'cyan'},
-                  'name': {'color': 'cyan'}}
-  level_styles = {'debug': {'color': 'white'},
-                  'info': {'color': 'green'},
-                  'warning': {'color': 'yellow'},
-                  'error': {'color': 'red'},
-                  'critical': {'color': 'red', 'bold': True}}
+  c_field_styles = {'asctime': {'color': 'magenta'},
+                    'hostname': {'color': 'magenta'},
+                    'levelname': {'bold': True, 'color': 'white'},
+                    'programname': {'color': 'cyan'},
+                    'name': {'color': 'cyan'}}
+  c_level_styles = {'debug': {'color': 'white'},
+                    'info': {'color': 'green'},
+                    'warning': {'color': 'yellow'},
+                    'error': {'color': 'red'},
+                    'critical': {'bold': True, 'color': 'red'}}
+  f_field_styles = {'asctime': {'color': 'magenta'},
+                    'hostname': {'color': 'magenta'},
+                    'levelname': {'color': 'white'},
+                    'programname': {'color': 'cyan'},
+                    'name': {'color': 'cyan'}}
+  f_level_styles = {'debug': {'color': 'white'},
+                    'info': {'color': 'green'},
+                    'warning': {'color': 'yellow'},
+                    'error': {'color': 'red'},
+                    'critical': {'color': 'red'}}
 
   def __init__(self, vault):
     self.handlers = {}
@@ -42,8 +52,8 @@ class Manager:
       console_handler.setFormatter(
           coloredlogs.ColoredFormatter(fmt=self.console_fmt,
                                        datefmt=self.datefmt,
-                                       level_styles=self.level_styles,
-                                       field_styles=self.field_styles))
+                                       level_styles=self.c_level_styles,
+                                       field_styles=self.c_field_styles))
     else:
       console_handler.setFormatter(logging.Formatter(fmt=self.console_fmt,
                                                      datefmt=self.datefmt))
@@ -89,8 +99,8 @@ class Manager:
     self.handlers[session].setFormatter(
         coloredlogs.ColoredFormatter(fmt=self.file_fmt,
                                      datefmt=self.datefmt,
-                                     level_styles=self.level_styles,
-                                     field_styles=self.field_styles))
+                                     level_styles=self.f_level_styles,
+                                     field_styles=self.f_field_styles))
     logging.getLogger().addHandler(self.handlers[session])
 
   def remove_file_handler(self, session):
