@@ -1,8 +1,5 @@
-import os
-import time
 import uuid
 import logging
-from laboro.history import History
 from laboro.workspace import Workspace
 
 
@@ -32,15 +29,8 @@ class Workflow:
   """
   def __init__(self, name, context):
     self.name = name
-    self.context = context
     self.session = str(uuid.uuid4())
-    self.context.configure_logger(self.name, self.session)
-    self.context.set_workflow_config(self.name)
-    self.history = History(filename=os.path.join(self.context.histdir,
-                                                 f"{self.name}.db"),
-                           workflow=self.name,
-                           session=self.session,
-                           params=self.context.configmgr.workflow_config)
+    self.context = context.reset(self.name, self.session)
     self.workspace = Workspace(workspacedir=self.context.workspacedir,
                                workflow=self.name,
                                session=self.session)
@@ -48,13 +38,13 @@ class Workflow:
   def __enter__(self):
     logging.getLogger().log_section("WORKFLOW",
                                     f"Started {self.name} / {self.session}")
-    self.history.__enter__()
+    self.context.history.enter()
     self.context.install_packages()
     return self
 
   def __exit__(self, kind, value, traceback):
     self.workspace.delete()
-    self.history.__exit__(kind, value, traceback)
+    self.context.history.exit(kind, value)
     exit_code = 0
     if kind == SystemExit:
       if value.code is not None:
@@ -89,5 +79,4 @@ class Workflow:
         logging.getLogger().log_section("ACTION",
                                         f"{step['name']} / {action['method']}")
         getattr(instance, action["method"])(**action_args)
-        time.sleep(2)
     logging.getLogger().log_section("WORKFLOW", "No more steps to run")
